@@ -6,6 +6,7 @@
 	2014.01.22 V00.01 Bug fixed for from_rig.c
 	2014.01.22 V00.02 Bug fixed for beep.c
 	2014.01.23 V00.03 drop "htons"
+	2014.01.23 V00.04 Added RnRoute messages routine
 
 */
 
@@ -189,7 +190,7 @@ void    AckSend(char srcRptCall[8])
         memcpy (ack_msg.Rep1Call, srcRptCall, 8);
         memcpy (ack_msg.dstCall, client_call, 8);
         sndAddr.sin_family = AF_INET;
-        sndAddr.sin_port = htons(trust_db_port);
+        sndAddr.sin_port = trust_db_port;
 	sndAddr.sin_addr = dbIP;
         sendto (udpSocket, (char *)&ack_msg, sizeof(ack_msg), 0,
                  (struct sockaddr *)&sndAddr, sizeof(sndAddr));
@@ -202,7 +203,7 @@ void	ConSend(void)
 	send_msg.type = ReqConnect;
 	send_msg.protocol = G3;
 	sndAddr.sin_family = AF_INET;
-	sndAddr.sin_port = htons(trust_db_port);
+	sndAddr.sin_port = trust_db_port;
 	sndAddr.sin_addr = dbIP;
 	sendto (udpSocket, (char *)&send_msg, sizeof (struct shm_form), 0,
 		(struct sockaddr *)&sndAddr, sizeof(sndAddr));
@@ -258,7 +259,7 @@ int main(int argc, const char **argv)
 
 	config (argc, (char **)argv);
 
-
+printf ("debug repeater mode %d\n",repeater_mode);
 	if (cmdmode == 0)
 	{
 		cmdin = 0;
@@ -307,7 +308,7 @@ int main(int argc, const char **argv)
 	//sockaddr_in 構造体のセット
 	bzero((char *)&dstAddr, sizeof(dstAddr));
 	dstAddr.sin_family = AF_INET;
-	dstAddr.sin_port = htons(trust_port);
+	dstAddr.sin_port = trust_port;
 	dstAddr.sin_addr = trustIP;
 
 	//ソケットの生成
